@@ -16,8 +16,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <gtk/gtk.h>
 
+#include <gtk/gtk.h>
 #include <hildon/hildon.h>
 #include <libhildondesktop/libhildondesktop.h>
 #include <mce/dbus-names.h>
@@ -475,15 +475,25 @@ connect_now_realize(GtkWidget* widget)
   ConnectNowHomePlugin *desktop_plugin = CONNECT_NOW_HOME_PLUGIN(widget);
   desktop_plugin->iD = hd_home_plugin_item_get_applet_id (HD_HOME_PLUGIN_ITEM (widget));
   read_settings(desktop_plugin);
-  if(desktop_plugin->connectedImage == NULL)
+/*   if(desktop_plugin->connectedImage == NULL) */
+/*   { */
+/*     desktop_plugin->connectedImageName = g_strdup(GENERAL_CONNECTED); */
+/*     desktop_plugin->connectedImage = load_image(desktop_plugin->connectedImageName); */
+/*   } */
+  if(desktop_plugin->fallback_connectedImage == NULL)
   {
-    desktop_plugin->connectedImageName = g_strdup(GENERAL_CONNECTED);
-    desktop_plugin->connectedImage = load_image(desktop_plugin->connectedImageName);
+    desktop_plugin->fallback_connectedImage = load_image(GENERAL_CONNECTED);
   }
-  if(desktop_plugin->disconnectedImage == NULL)
+
+/*   if(desktop_plugin->disconnectedImage == NULL) */
+/*   { */
+/*     desktop_plugin->disconnectedImageName = g_strdup(GENERAL_DISCONNECTED); */
+/*     desktop_plugin->disconnectedImage = load_image(desktop_plugin->disconnectedImageName); */
+/*   } */
+
+  if(desktop_plugin->fallback_disconnectedImage == NULL)
   {
-    desktop_plugin->disconnectedImageName = g_strdup(GENERAL_DISCONNECTED);
-    desktop_plugin->disconnectedImage = load_image(desktop_plugin->disconnectedImageName);
+    desktop_plugin->fallback_disconnectedImage = load_image(GENERAL_DISCONNECTED);
   }
   gtk_window_resize(GTK_WINDOW(widget),
 		    desktop_plugin->widget_size,
@@ -506,19 +516,36 @@ connect_now_expose(GtkWidget* widget, GdkEventExpose *event)
   int width = CONNECT_NOW_HOME_PLUGIN(widget)->widget_size;
   cairo_scale(cr, width/100.0, width/100.0);
 
-
   GdkPixbuf* image = NULL;
+
   if(CONNECT_NOW_HOME_PLUGIN(widget)->this_connection_state == CON_IC_STATUS_CONNECTED)
   {
-    image = CONNECT_NOW_HOME_PLUGIN(widget)->connectedImage;
+    if((image = CONNECT_NOW_HOME_PLUGIN(widget)->connectedImage) == NULL)
+    {
+      CONNECT_NOW_HOME_PLUGIN(widget)->connectedImage = load_image(CONNECT_NOW_HOME_PLUGIN(widget)->connectedImageName);
+      if((image = CONNECT_NOW_HOME_PLUGIN(widget)->connectedImage) == NULL)
+      {
+	image = CONNECT_NOW_HOME_PLUGIN(widget)->fallback_connectedImage;
+      }
+    }
   }
   else
   {
-    image = CONNECT_NOW_HOME_PLUGIN(widget)->disconnectedImage;
+    if((image = CONNECT_NOW_HOME_PLUGIN(widget)->disconnectedImage) == NULL)
+    {
+      CONNECT_NOW_HOME_PLUGIN(widget)->disconnectedImage = load_image(CONNECT_NOW_HOME_PLUGIN(widget)->disconnectedImageName);
+      if((image = CONNECT_NOW_HOME_PLUGIN(widget)->disconnectedImage) == NULL)
+      {
+	image = CONNECT_NOW_HOME_PLUGIN(widget)->fallback_disconnectedImage;
+      }
+    }
   }
 
-  gdk_cairo_set_source_pixbuf(cr, image, 0.0, 0.0);
-  cairo_paint(cr);
+  if(image != NULL)
+  {
+    gdk_cairo_set_source_pixbuf(cr, image, 0.0, 0.0);
+    cairo_paint(cr);
+  }
 
   if(!CONNECT_NOW_HOME_PLUGIN(widget)->hide_connection_name)
   {
@@ -578,6 +605,10 @@ connect_now_plugin_finalize(GObject *object)
     g_object_unref(desktop_plugin->connectedImage);
   if(desktop_plugin->disconnectedImage)
     g_object_unref(desktop_plugin->disconnectedImage);
+  if(desktop_plugin->fallback_connectedImage)
+    g_object_unref(desktop_plugin->fallback_connectedImage);
+  if(desktop_plugin->disconnectedImage)
+    g_object_unref(desktop_plugin->fallback_disconnectedImage);
   G_OBJECT_CLASS (connect_now_home_plugin_parent_class)->finalize (object);
 }
 
